============================================================
:mod:`XRootD.client.FileSystem`: Filesystem-based operations
============================================================

Class Reference
---------------

.. module:: XRootD.client

.. autoclass:: XRootD.client.FileSystem

Attributes
**********

.. autoattribute:: XRootD.client.FileSystem.url

Methods
*******

.. automethod:: XRootD.client.FileSystem.copy
.. automethod:: XRootD.client.FileSystem.locate
.. automethod:: XRootD.client.FileSystem.deeplocate
.. automethod:: XRootD.client.FileSystem.mv
.. automethod:: XRootD.client.FileSystem.query
.. automethod:: XRootD.client.FileSystem.truncate
.. automethod:: XRootD.client.FileSystem.rm
.. automethod:: XRootD.client.FileSystem.mkdir
.. automethod:: XRootD.client.FileSystem.rmdir
.. automethod:: XRootD.client.FileSystem.chmod
.. automethod:: XRootD.client.FileSystem.ping
.. automethod:: XRootD.client.FileSystem.stat
.. automethod:: XRootD.client.FileSystem.statvfs
.. automethod:: XRootD.client.FileSystem.protocol
.. automethod:: XRootD.client.FileSystem.dirlist
.. automethod:: XRootD.client.FileSystem.sendinfo
.. automethod:: XRootD.client.FileSystem.prepare
.. automethod:: XRootD.client.FileSystem.set_property
.. automethod:: XRootD.client.FileSystem.get_property
